@@ -2,7 +2,7 @@ import datacollector_ECB
 import datacollector_ICE
 import datacollector_Boliga
 import datacollector_Business_insider
-import datacollector_Entsoe_v2
+import datacollector_Entsoe
 
 
 class ECB(datacollector_ECB.ECB):
@@ -11,7 +11,7 @@ class ECB(datacollector_ECB.ECB):
 class ICE(datacollector_ICE.ICE):
     pass
 
-class Entsoe(datacollector_Entsoe_v2.Entsoe):
+class Entsoe(datacollector_Entsoe.Entsoe):
     pass
 
 class Boliga(datacollector_Boliga.Boliga):
